@@ -23,10 +23,11 @@ if(length(classifiers) > 0) {
 
   ### use raw data
   dat <- iris
-  true <- iris$Species
+  f <- Species ~ .
+  true <- response(f, dat)
 
   for(cl in classifiers) {
-    res <- cl(Species ~ ., dat)
+    res <- cl(f, dat)
     print(res)
 
     p <- predict(res, dat)
@@ -36,8 +37,8 @@ if(length(classifiers) > 0) {
   }
 
   ### use transactions
-  dat <- as(discretizeDF.supervised(Species ~ ., iris), "transactions")
-  true <- iris$Species
+  dat <- prepareTransactions(f, iris)
+  true <- response(f, dat)
 
   for(cl in classifiers) {
     res <- cl(Species ~ ., dat)
@@ -48,5 +49,20 @@ if(length(classifiers) > 0) {
     accuracy <- sum(diag(tbl))/ sum(tbl)
     cat("Accuracy:", round(accuracy, 3), "\n\n")
   }
+
+  data(Groceries)
+  dat <- sample(Groceries, 500)
+  f <- `bottled beer` ~ .
+  true <- response(f, dat)
+
+  for(cl in classifiers) {
+    res <- cl(f, dat)
+    print(res)
+
+    p <- predict(res, dat)
+    tbl <- table(p, true)
+    accuracy <- sum(diag(tbl))/ sum(tbl)
+    cat("Accuracy:", round(accuracy, 3), "\n\n")
+  }
 }
 
